/*
 * Copyright (C) 2010 SHARP Corporation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package jp.co.sharp.android.samples.pedometer;

import android.appwidget.AppWidgetManager;
import android.appwidget.AppWidgetProvider;
import android.content.Context;
import android.content.Intent;

/**
 * Widgetがホームに追加されるとサービスを開始する。
 * Widgetがホームから消去されるとサービスを停止する。
 */
public class SamplePedometerWidgetProvider extends AppWidgetProvider {

    /**
     * Widgetがホームに追加された後の処理です。
     * onUpdateをオーバーライドしています。
     * @param context context
     * @param appWidgetManager appWidgetManager
     * @param appWidgetIds appWidgetIds
     */
    @Override
    public void onUpdate(Context context, AppWidgetManager appWidgetManager, int[] appWidgetIds) {
        if(null == context) {
            return;
        }
        if(null == appWidgetManager) {
            return;
        }
        // サービス開始
        Intent intent = new Intent(context, SamplePedometerWidgetService.class);
        context.startService(intent);

    }
    
    /**
     * Widgetがホームから削除される際の処理です。
     * onDisabledをオーバーライドしています。
     * @param context context
     */
    @Override
    public void onDisabled(Context context)  {
        super.onDisabled(context) ;
        // サービス停止
        Intent intent = new Intent(context, SamplePedometerWidgetService.class);
        context.stopService(intent);
    }

}
